@@ -29,14 +29,15 @@
 
 #ifndef _GNUstep_H_NSActionCell
 #define _GNUstep_H_NSActionCell
-#import <GNUstepBase/GSVersionMacros.h>
+#import <AppKit/AppKitDefines.h>
 
-#include <AppKit/NSCell.h>
+#import <AppKit/NSCell.h>
 
+APPKIT_EXPORT_CLASS
 @interface NSActionCell : NSCell
 {
   // Attributes
-  int _tag;
+  NSInteger _tag;
   id _target;
   SEL _action;
   NSView *_control_view; 
