@@ -30,7 +30,7 @@
 
 #ifndef _GNUstep_H_NSButtonCell
 #define _GNUstep_H_NSButtonCell
-#import <GNUstepBase/GSVersionMacros.h>
+#import <AppKit/AppKitDefines.h>
 
 #import <AppKit/NSActionCell.h>
 
@@ -78,6 +78,10 @@ typedef enum _NSButtonType {
   NSMomentaryChangeButton,
   NSOnOffButton,
   NSMomentaryPushInButton,
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_10, GS_API_LATEST)
+  NSAcceleratorButton,
+  NSMultiLevelAcceleratorButton,
+#endif
   // These are old names
   NSMomentaryLight = NSMomentaryPushInButton,
   NSMomentaryPushButton = NSMomentaryLightButton
@@ -115,6 +119,7 @@ typedef enum _NSGradientType {
 } NSGradientType;
 
 
+APPKIT_EXPORT_CLASS
 @interface NSButtonCell : NSActionCell
 {
   // Attributes
@@ -123,9 +128,9 @@ typedef enum _NSGradientType {
   NSString *_keyEquivalent;
   NSFont *_keyEquivalentFont;
   NSSound *_sound;
-  unsigned int _keyEquivalentModifierMask;
-  unsigned int _highlightsByMask;
-  unsigned int _showAltStateMask;
+  NSUInteger _keyEquivalentModifierMask;
+  NSInteger _highlightsByMask;
+  NSInteger _showAltStateMask;
   float _delayInterval;
   float _repeatInterval;
   NSBezelStyle _bezel_style;
@@ -136,6 +141,7 @@ typedef enum _NSGradientType {
 #define _image_dims_when_disabled _cell.subclass_bool_two
 #define _shows_border_only_while_mouse_inside _cell.subclass_bool_three
 #define _mouse_inside _cell.subclass_bool_four
+  NSImageScaling _imageScaling;
 }
 
 //
@@ -153,8 +159,8 @@ typedef enum _NSGradientType {
 - (void)setAttributedTitle: (NSAttributedString *)aString;
 - (void)setTitleWithMnemonic: (NSString *)aString;
 - (NSString *)alternateMnemonic;
-- (unsigned)alternateMnemonicLocation;
-- (void)setAlternateMnemonicLocation: (unsigned)location;
+- (NSUInteger)alternateMnemonicLocation;
+- (void)setAlternateMnemonicLocation: (NSUInteger)location;
 - (void)setAlternateTitleWithMnemonic: (NSString *)aString;
 #endif
 
@@ -165,6 +171,10 @@ typedef enum _NSGradientType {
 - (NSCellImagePosition)imagePosition;
 - (void)setAlternateImage: (NSImage *)anImage;
 - (void)setImagePosition: (NSCellImagePosition)aPosition;
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
+- (NSImageScaling)imageScaling;
+- (void)setImageScaling:(NSImageScaling)scaling;
+#endif
 
 //
 // Setting the Repeat Interval 
@@ -179,9 +189,9 @@ typedef enum _NSGradientType {
 //
 - (NSString *)keyEquivalent;
 - (NSFont *)keyEquivalentFont;
-- (unsigned int)keyEquivalentModifierMask;
+- (NSUInteger)keyEquivalentModifierMask;
 - (void)setKeyEquivalent: (NSString *)key;
-- (void)setKeyEquivalentModifierMask: (unsigned int)mask;
+- (void)setKeyEquivalentModifierMask: (NSUInteger)mask;
 - (void)setKeyEquivalentFont: (NSFont *)fontObj;
 - (void)setKeyEquivalentFont: (NSString *)fontName 
 			size: (float)fontSize;
@@ -208,19 +218,19 @@ typedef enum _NSGradientType {
 - (void) drawImage: (NSImage*)imageToDisplay 
          withFrame: (NSRect)cellFrame 
             inView: (NSView *)controlView;
-- (void) drawTitle: (NSAttributedString*)titleToDisplay 
-         withFrame: (NSRect)cellFrame 
-            inView: (NSView *)controlView;
+- (NSRect) drawTitle: (NSAttributedString*)titleToDisplay
+           withFrame: (NSRect)cellFrame
+              inView: (NSView *)controlView;
 #endif
 
 //
 // Modifying Graphic Attributes 
 //
-- (int)highlightsBy;
-- (void)setHighlightsBy: (int)mask;
-- (void)setShowsStateBy: (int)mask;
+- (NSInteger)highlightsBy;
+- (void)setHighlightsBy: (NSInteger)mask;
+- (void)setShowsStateBy: (NSInteger)mask;
 - (void)setButtonType: (NSButtonType)buttonType;
-- (int)showsStateBy;
+- (NSInteger)showsStateBy;
 
 //
 // Sound
