@@ -29,10 +29,11 @@
 
 #ifndef _GNUstep_H_NSFormCell
 #define _GNUstep_H_NSFormCell
-#import <GNUstepBase/GSVersionMacros.h>
+#import <AppKit/AppKitDefines.h>
 
-#include <AppKit/NSActionCell.h>
+#import <AppKit/NSActionCell.h>
 
+APPKIT_EXPORT_CLASS
 @interface NSFormCell : NSActionCell <NSCoding>
 {
   // NB: this is the titleWidth which is effectively used -- takes in
@@ -54,12 +55,12 @@
 - (void)setTitle:(NSString*)aString;
 - (void)setTitleAlignment:(NSTextAlignment)mode;
 - (void)setTitleFont:(NSFont*)fontObject;
-- (void)setTitleWidth:(float)width;
+- (void)setTitleWidth:(CGFloat)width;
 - (NSString*)title;
 - (NSTextAlignment)titleAlignment;
 - (NSFont*)titleFont;
-- (float)titleWidth;
-- (float)titleWidth:(NSSize)aSize;
+- (CGFloat)titleWidth;
+- (CGFloat)titleWidth:(NSSize)aSize;
 
 #if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 //
