@@ -29,29 +29,10 @@
 
 #ifndef _GNUstep_H_NSImageCell
 #define _GNUstep_H_NSImageCell
-#import <GNUstepBase/GSVersionMacros.h>
+#import <AppKit/AppKitDefines.h>
 
 #import <AppKit/NSCell.h>
 
-/**
- *  <p>Enumeration of the ways that you can display an image in an
- *  NSImageCell.  The available ones are:</p>
- *  <p><code>NSScaleNone</code>: The image is always displayed with
- *  its natural size.  If it's bigger than the cell size, it is
- *  cropped.</p>
- *  <p><code>NSScaleProportionally</code>: If the image is bigger
- *  than the cell size, it is displayed in its natural size.  If it
- *  is smaller than the cell size, it is resized down proportionally
- *  to fit the cell size.</p>
- *  <p><code>NSScaleToFit</code>: The image is always resized (up
- *  or down) to fit exactly in the cell size.</p>
- */
-typedef enum {
-    NSScaleProportionally = 0,
-    NSScaleToFit,
-    NSScaleNone
-} NSImageScaling;
-
 /**
  *  <p>Enumeration of the ways that you can align an image inside an
  *  NSImageCell when the image is not taking up all the space inside
@@ -104,6 +85,7 @@ typedef enum {
  *  <p>The -setImageFrameStyle: method can be used to control if the
  *  cell should display a frame border, and which one.</p>
  */
+APPKIT_EXPORT_CLASS
 @interface NSImageCell : NSCell
 {
   NSImageAlignment _imageAlignment;
