@@ -28,7 +28,7 @@
 
 #ifndef _GNUstep_H_NSMenu
 #define _GNUstep_H_NSMenu
-#import <GNUstepBase/GSVersionMacros.h>
+#import <AppKit/AppKitDefines.h>
 
 #import <Foundation/NSObject.h>
 #import <Foundation/NSGeometry.h>
@@ -386,6 +386,7 @@
  *  </enum>
  *
  */
+APPKIT_EXPORT_CLASS
 @interface NSMenu : NSObject <NSCoding, NSCopying>
 {
   NSString *_title;
@@ -434,6 +435,12 @@
                  withFont: (NSFont *)font;
 #endif
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST)
+- (void) popUpMenuPositionItem: (NSMenuItem *)item
+                    atLocation: (NSPoint) point
+                        inView: (NSView *) view;
+#endif
+
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_2, GS_API_LATEST)
 + (BOOL) menuBarVisible;
 + (void) setMenuBarVisible: (BOOL)flag;
@@ -820,5 +827,7 @@ APPKIT_EXPORT NSString* const NSMenuWillSendActionNotification;
 APPKIT_EXPORT NSString* const NSMenuDidAddItemNotification;
 APPKIT_EXPORT NSString* const NSMenuDidRemoveItemNotification;
 APPKIT_EXPORT NSString* const NSMenuDidChangeItemNotification;
+APPKIT_EXPORT NSString* const NSMenuDidBeginTrackingNotification;
+APPKIT_EXPORT NSString* const NSMenuDidEndTrackingNotification;
 
 #endif // _GNUstep_H_NSMenu
