@@ -36,10 +36,10 @@
 
 #ifndef _GNUstep_H_NSPrintOperation
 #define _GNUstep_H_NSPrintOperation
-#import <GNUstepBase/GSVersionMacros.h>
+#import <AppKit/AppKitDefines.h>
 
-#include <Foundation/NSObject.h>
-#include <Foundation/NSGeometry.h>
+#import <Foundation/NSObject.h>
+#import <Foundation/NSGeometry.h>
 
 @class NSString;
 @class NSData;
@@ -58,6 +58,7 @@ typedef enum _NSPrintingPageOrder {
   NSUnknownPageOrder
 } NSPrintingPageOrder;
 
+APPKIT_EXPORT_CLASS
 @interface NSPrintOperation : NSObject
 {
   // Attributes
