@@ -30,13 +30,28 @@
 
 #ifndef _GNUstep_H_NSScroller
 #define _GNUstep_H_NSScroller
-#import <GNUstepBase/GSVersionMacros.h>
+#import <AppKit/AppKitDefines.h>
 
 #import <AppKit/NSControl.h>
 #import <AppKit/NSCell.h>
 
 @class NSEvent;
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_7, GS_API_LATEST)
+enum {
+  NSScrollerStyleLegacy = 0,
+  NSScrollerStyleOverlay = 1
+};
+typedef NSInteger NSScrollerStyle;
+
+enum {
+  NSScrollerKnobStyleDefault = 0,
+  NSScrollerKnobStyleDark = 1,
+  NSScrollerKnobStyleLight = 2
+};
+typedef NSInteger NSScrollerKnobStyle;
+#endif
+
 enum _NSScrollArrowPosition {
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_1, GS_API_LATEST)
   NSScrollerArrowsDefaultSetting = 0,
@@ -71,6 +86,7 @@ enum _NSScrollerArrow {
 };
 typedef NSUInteger NSScrollerArrow;
 
+APPKIT_EXPORT_CLASS
 @interface NSScroller : NSControl <NSCoding>
 {
   double _doubleValue;
@@ -90,6 +106,10 @@ typedef NSUInteger NSScrollerArrow;
   } _scFlags;
 }
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_7, GS_API_LATEST)
++ (NSScrollerStyle)preferredScrollerStyle;
+#endif
+
 //
 // Laying out the NSScroller 
 //
@@ -144,4 +164,6 @@ typedef NSUInteger NSScrollerArrow;
 
 @end
 
+APPKIT_EXPORT NSString *NSPreferredScrollerStyleDidChangeNotification;
+
 #endif // _GNUstep_H_NSScroller
