@@ -38,15 +38,16 @@
 @class NSColor;
 @class NSEvent;
 
+APPKIT_EXPORT_CLASS
 @interface NSSlider : NSControl
 // appearance 
 - (double) altIncrementValue;
 - (NSImage*) image;
-- (int) isVertical;
-- (float) knobThickness;
+- (NSInteger) isVertical;
+- (CGFloat) knobThickness;
 - (void) setAltIncrementValue: (double)increment;
 - (void) setImage: (NSImage*)backgroundImage;
-- (void) setKnobThickness: (float)aFloat;
+- (void) setKnobThickness: (CGFloat)aFloat;
 
 // title
 - (NSString*) title;
@@ -71,14 +72,14 @@
 // ticks
 - (BOOL) allowsTickMarkValuesOnly;
 - (double) closestTickMarkValueToValue: (double)aValue;
-- (int) indexOfTickMarkAtPoint: (NSPoint)point;
-- (int) numberOfTickMarks;
-- (NSRect) rectOfTickMarkAtIndex: (int)index;
+- (NSInteger) indexOfTickMarkAtPoint: (NSPoint)point;
+- (NSInteger) numberOfTickMarks;
+- (NSRect) rectOfTickMarkAtIndex: (NSInteger)index;
 - (void) setAllowsTickMarkValuesOnly: (BOOL)flag;
-- (void) setNumberOfTickMarks: (int)numberOfTickMarks;
+- (void) setNumberOfTickMarks: (NSInteger)numberOfTickMarks;
 - (void) setTickMarkPosition: (NSTickMarkPosition)position;
 - (NSTickMarkPosition) tickMarkPosition;
-- (double) tickMarkValueAtIndex: (int)index;
+- (double) tickMarkValueAtIndex: (NSInteger)index;
 #endif
 
 @end
