@@ -3,9 +3,9 @@
 
    Copyright (C) 1996,1999 Free Software Foundation, Inc.
 
-   Author:  Daniel Bhringer <boehring@biomed.ruhr-uni-bochum.de>
+   Author:  Daniel Böhringer <boehring@biomed.ruhr-uni-bochum.de>
    Date: August 1998
-   Source by Daniel Bhringer integrated into GNUstep gui
+   Source by Daniel Böhringer integrated into GNUstep gui
    by Felipe A. Rodriguez <far@ix.netcom.com> 
    Update: Richard Frith-Macdonald <richard@brainstorm.co.uk>
 
@@ -34,11 +34,16 @@
 #ifndef _GNUstep_H_NSTextStorage
 #define _GNUstep_H_NSTextStorage
 
-#include <AppKit/NSStringDrawing.h>
-#include <AppKit/AppKitDefines.h>
+#import <Foundation/NSAttributedString.h>
+#import <Foundation/NSGeometry.h>
+#import <Foundation/NSObject.h>
+#import <AppKit/AppKitDefines.h>
 
 @class NSNotification;
+@class NSString;
 @class GSLayoutManager;
+@class NSFont;
+@class NSColor;
 
 /*
  * When edit:range:changeInLength: is called, it takes a mask saying
@@ -54,17 +59,20 @@ enum
   NSTextStorageEditedCharacters = 2
 };
 
+typedef NSUInteger NSTextStorageEditedOptions;
+
 /* 
  * The NSTextStorage 
  */
+APPKIT_EXPORT_CLASS
 @interface NSTextStorage : NSMutableAttributedString
 {
   NSRange		_editedRange;
-  int			_editedDelta;
+  NSInteger		_editedDelta;
   NSMutableArray	*_layoutManagers;
   id			_delegate;
-  unsigned		_editedMask;
-  unsigned		_editCount;
+  NSTextStorageEditedOptions _editedMask;
+  NSUInteger		_editCount;
 }
 
 - (void) addLayoutManager: (GSLayoutManager*)obj;
@@ -93,7 +101,7 @@ enum
  *
  * the changeInLength is, well, positive if you added characters, negative
  * if you removed characters.  */
-- (void) edited: (unsigned)mask range: (NSRange)old changeInLength: (int)delta;
+- (void) edited: (NSTextStorageEditedOptions)mask range: (NSRange)old changeInLength: (NSInteger)delta;
 
 /*
  * This method is called to process the editing once it's finished.
@@ -133,9 +141,9 @@ enum
  * The delegate can use the following methods when it receives a
  * notification that a change was made.  The methods tell him what
  * kind of change was made.  */
-- (unsigned) editedMask;
+- (NSTextStorageEditedOptions) editedMask;
 - (NSRange) editedRange;
-- (int) changeInLength;
+- (NSInteger) changeInLength;
 
 - (void) setDelegate: (id)delegate;
 - (id) delegate;
@@ -146,6 +154,17 @@ enum
 - (void) invalidateAttributesInRange: (NSRange)range;
 #endif
 
+/** Returns the string data stored by the receiver.<br />
+ * For performance reasons (and OSX compatibility) this is actually
+ * a proxy to the internal representation of the string.<br />
+ * This proxy provides an immutable string interface,
+ * but you must be aware that the underlying information may be modified
+ * by the receiver at any point, so if you need a consistent/fixed
+ * snapshot of the data (or if you are going to pass the string to other
+ * code which expects to be working with a constant string), you should
+ * copy the object returned by this method rather than simply retaining it.
+ */
+- (NSString*) string;
 @end
 
 
@@ -167,6 +186,39 @@ enum
 
 @end
 
+@interface NSTextStorage (Scripting)
+/*
+ * Attributes for string...
+*/
+- (NSFont*) font;
+- (void) setFont: (NSFont*)font;
+
+/*
+ * The text storage contents as an array of attribute runs.
+ */
+- (NSArray *)attributeRuns;
+
+/*
+ * The text storage contents as an array of paragraphs.
+ */
+- (NSArray *)paragraphs;
+
+/*
+ * The text storage contents as an array of words.
+ */
+- (NSArray *)words;
+
+/*
+ * The text storage contents as an array of characters.
+ */
+- (NSArray *)characters;
+
+/*
+ * The font color used when drawing text.
+ */
+- (NSColor *)foregroundColor;
+@end
+
 /**** Notifications ****/
 
 /* The object of the notification is the NSTextStorage itself.  */
