@@ -25,6 +25,7 @@
 
 #ifndef _NSTouchBarItem_h_GNUSTEP_GUI_INCLUDE
 #define _NSTouchBarItem_h_GNUSTEP_GUI_INCLUDE
+#import <AppKit/AppKitDefines.h>
 
 #import <Foundation/NSObject.h>
 
@@ -34,6 +35,7 @@
 extern "C" {
 #endif
 
+APPKIT_EXPORT_CLASS
 @interface NSTouchBarItem : NSObject
 
 @end
