@@ -252,6 +252,8 @@
 @class NSProgressIndicator;
 @class NSTableHeaderCell;
 @class NSTabViewItem;
+@class NSPathControl;
+@class NSPathComponentCell;
 @class GSDrawTiles;
 @class GSTitleView;
 
@@ -389,6 +391,22 @@ typedef enum {
   GSThemeSelectedState		/** A control which is selected */
 } GSThemeControlState;
 
+/**
+ * This enumeration is used when selecting the NSTabView.
+ */
+typedef enum {
+  GSTabSelectedLeft,
+  GSTabSelectedRight,
+  GSTabSelectedToUnSelectedJunction,
+  GSTabSelectedFill,
+  GSTabUnSelectedLeft,
+  GSTabUnSelectedRight,
+  GSTabUnSelectedToSelectedJunction,
+  GSTabUnSelectedJunction,
+  GSTabUnSelectedFill,
+  GSTabBackgroundFill
+} GSTabPart;
+
 /** Notification sent when a theme has just become active.<br />
  * The notification is posted by the -activate method.<br />
  * This is primarily for internal use by AppKit controls which
@@ -464,6 +482,7 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
   use the appropriate behavior.
   </p>
 */ 
+APPKIT_EXPORT_CLASS
 @interface GSTheme : NSObject
 {
 @private
@@ -958,6 +977,27 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  */
 - (void) drawStepperHighlightDownButton: (NSRect)aRect;
 
+// NSSwitch drawing methods
+- (void) drawSwitchKnob: (NSRect)frame
+               forState: (NSControlStateValue)value
+                enabled: (BOOL)enabled;
+
+
+- (void) drawSwitchBezel: (NSRect)frame
+                forState: (NSControlStateValue)v
+                 enabled: (BOOL)enabled;
+
+- (void) drawSwitchInRect: (NSRect)rect
+                 forState: (NSControlStateValue)state
+                  enabled: (BOOL)enabled;
+
+// NSPathComponentCell
+
+- (void) drawPathComponentCellWithFrame: (NSRect)f
+                                 inView: (NSPathControl *)pc
+                               withCell: (NSPathComponentCell *)cell
+                        isLastComponent: (BOOL)last;
+
 // NSSegmentedControl drawing methods
 
 - (void) drawSegmentedControlSegment: (NSCell *)cell
@@ -977,9 +1017,12 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  * <p>The returned color is used by 
  * -drawBackgroundForMenuView:withFrame:dirtyRect:horizontal:</p>
  * 
- * <p>Can be overridden in subclasses to return a custom color.</p>
+ * <p>Can be overridden in subclasses to return a custom color, but generally
+ * should not.  Instead themes should provide default colors in the
+ * GSThemeDomain (in their Info.plist).</p>
  */
 - (NSColor *) menuBackgroundColor;
+
 /**
  * <p>Returns the color used to draw a menu item background.</p>
  *
@@ -994,11 +1037,14 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  * -drawBorderAndBackgroundForMenuItemCell:withFrame:inView:state:isHorizontal: 
  * and [NSMenuItemCell-backgroundColor].</p>
  * 
- * <p>Can be overridden in subclasses to return a custom color.</p>
+ * <p>Can be overridden in subclasses to return a custom color, but generally
+ * should not.  Instead themes should provide default colors in the
+ * GSThemeDomain (in their Info.plist).</p>
  */
 - (NSColor *) menuItemBackgroundColor;
 - (NSColor *) menuBarBackgroundColor;
 - (NSColor *) menuBarBorderColor;
+
 /**
  * <p>Returns the color used to draw a menu view border.</p>
  *
@@ -1008,9 +1054,12 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  * <p>The returned color is used by 
  * -drawBackgroundForMenuView:withFrame:dirtyRect:horizontal:</p>
  * 
- * <p>Can be overridden in subclasses to return a custom color.</p>
+ * <p>Can be overridden in subclasses to return a custom color, but generally
+ * should not.  Instead themes should provide default colors in the
+ * GSThemeDomain (in their Info.plist).</p>
  */
 - (NSColor *) menuBorderColor;
+
 /**
  * <p>Returns a color to draw each edge in a menu view border.</p>
  *
@@ -1020,7 +1069,9 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  * <p>The returned edge color is used by 
  * -drawBackgroundForMenuView:withFrame:dirtyRect:horizontal:</p>
  * 
- * <p>Can be overridden in subclasses to return a custom color per edge.</p>
+ * <p>Can be overridden in subclasses to return a custom color, but generally
+ * should not.  Instead themes should provide default colors in the
+ * GSThemeDomain (in their Info.plist).</p>
  */
 - (NSColor *) menuBorderColorForEdge: (NSRectEdge)edge 
                         isHorizontal: (BOOL)horizontal;
@@ -1037,7 +1088,9 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  * <p>The returned value used by 
  * -drawBorderAndBackgroundForMenuItemCell:withFrame:inView:state:isHorizontal:</p>
  * 
- * <p>Can be overridden in subclasses.</p>
+ * <p>Can be overridden in subclasses to return a custom color, but generally
+ * should not.  Instead themes should provide default colors in the
+ * GSThemeDomain (in their Info.plist).</p>
  */
 - (BOOL) drawsBorderForMenuItemCell: (NSMenuItemCell *)cell 
                               state: (GSThemeControlState)state
@@ -1078,9 +1131,12 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  * <p>The returned color is used by 
  * -drawSeparatorItemForMenuItemCell:withFrame:inView:isHorizontal:</p>
  * 
- * <p>Can be overridden in subclasses to return a custom color.</p>
+ * <p>Can be overridden in subclasses to return a custom color, but generally
+ * should not.  Instead themes should provide default colors in the
+ * GSThemeDomain (in their Info.plist).</p>
  */
 - (NSColor *) menuSeparatorColor;
+
 /**
  * <p>Returns the left and right inset used to draw a separator line in a
  * menu.</p>
@@ -1090,7 +1146,9 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  * <p>The returned color is used by 
  * -drawSeparatorItemForMenuItemCell:withFrame:inView:isHorizontal:</p>
  * 
- * <p>Can be overridden in subclasses to return a custom value.</p>
+ * <p>Can be overridden in subclasses to return a custom color, but generally
+ * should not.  Instead themes should provide default colors in the
+ * GSThemeDomain (in their Info.plist).</p>
  */
 - (CGFloat) menuSeparatorInset;
 
@@ -1170,6 +1228,8 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
 
 - (float) resizebarHeight;
 
+- (float) resizebarNotchWidth;
+
 - (float) titlebarButtonSize;
 
 - (float) titlebarPaddingRight;
@@ -1452,9 +1512,11 @@ withRepeatedImage: (NSImage*)image
 @end
 
 // Panels which can be overridden by the theme...
+APPKIT_EXPORT_CLASS
 @interface GSPrintPanel : NSPrintPanel
 @end
 
+APPKIT_EXPORT_CLASS
 @interface GSPageLayout : NSPageLayout
 @end
 
